# Flot Examples

There are plenty of options you can set to control the precise looks of your plot. You can control the axes, the legend, the default graph type, the look of grid, etc.

The idea is that Flot goes to great lengths to provide sensible defaults which you can then customize as needed for your particular application. If you've found a use case where the defaults can be improved, please don't hesitate to give your feedback.